Struct TypstVersion
pub struct TypstVersion { /* private fields */ }Expand description
Typst version definition.
This structure contains the current Typst version. To query the precise
version number, refer to the TypstVersion::major(),
TypstVersion::minor() and TypstVersion::patch() functions. You can
read the underlying, raw version string (e.g., for CLI output) with
TypstVersion::raw.
Optionally, this may also contain the hash value of the Git commit from which Typst was built. However, this field may be unpopulated.
Implementations
impl TypstVersion
impl TypstVersion